@@ -21,24 +21,60 @@
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 
-GtkWidget* progress;
-GtkWidget* label;
-GtkWidget* splash;
+static GtkWidget* progress = NULL;
+static GtkWidget* label = NULL;
+static GtkWidget* splash = NULL;
+static gboolean waiting_for_expose = FALSE;
 
 void 
 splash_update (gchar* text, gfloat percent)
 {
-  gtk_label_set (GTK_LABEL (label), text);
-  gtk_progress_set_percentage (GTK_PROGRESS (progress), percent); 
-  while (gtk_events_pending ()) gtk_main_iteration ();
+	if (label != NULL &&
+	    progress != NULL) {
+		gtk_label_set (GTK_LABEL (label), text);
+		gtk_progress_set_percentage (GTK_PROGRESS (progress), percent); 
+		while (gtk_events_pending ())
+			gtk_main_iteration ();
+	}
 }
 
+static void
+splash_destroyed (GtkWidget *w)
+{
+	splash = NULL;
+	label = NULL;
+	progress = NULL;
+	if (waiting_for_expose) {
+		waiting_for_expose = FALSE;
+		gtk_main_quit ();
+	}
+}
+
+static gboolean
+expose_event (GtkWidget *w, GdkEventExpose *event)
+{
+	if (waiting_for_expose) {
+		waiting_for_expose = FALSE;
+		gtk_main_quit ();
+	}
+}
+
+
 void 
 splash_new ()
 {
-  gchar* image_file = gnome_pixmap_file ("cards/splash.png");
-  GtkWidget* splash_pixmap = gnome_pixmap_new_from_file (image_file);
-  GtkWidget* vbox = gtk_vbox_new(FALSE, GNOME_PAD);
+  gchar* image_file;
+  GtkWidget* splash_pixmap = NULL;
+  GtkWidget* vbox;
+
+  image_file = gnome_pixmap_file ("cards/splash.png");
+
+  if (image_file != NULL)
+	  splash_pixmap = gnome_pixmap_new_from_file (image_file);
+
+  g_free (image_file);
+
+  vbox = gtk_vbox_new(FALSE, GNOME_PAD);
 
   progress = gtk_progress_bar_new ();
   label = gtk_label_new ("");
@@ -49,27 +85,37 @@ splash_new ()
   gtk_window_set_title (GTK_WINDOW (splash), _("AisleRiot"));
   gtk_window_set_policy (GTK_WINDOW (splash), FALSE, FALSE, FALSE);
   gnome_window_icon_set_from_default (GTK_WINDOW (splash));
+  gtk_signal_connect (GTK_OBJECT (splash), "destroy",
+		      GTK_SIGNAL_FUNC (splash_destroyed),
+		      NULL);
   
   gtk_container_border_width (GTK_CONTAINER (vbox), 0);
   gtk_container_add(GTK_CONTAINER(splash), vbox);
 
-  gtk_box_pack_start (GTK_BOX (vbox), splash_pixmap, FALSE, FALSE, 
-		      GNOME_PAD_SMALL);
+  if (splash_pixmap != NULL)
+	  gtk_box_pack_start (GTK_BOX (vbox), splash_pixmap, FALSE, FALSE, 
+			      GNOME_PAD_SMALL);
   gtk_box_pack_end (GTK_BOX (vbox), progress, FALSE, FALSE, GNOME_PAD_SMALL);
   gtk_box_pack_end (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   
   gtk_widget_show_all (splash);
 
   /* Give window manager time to map the window */
-  gtk_signal_connect (GTK_OBJECT (splash_pixmap), "expose_event",
-		      GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
-  gtk_main ();
+  if (splash_pixmap != NULL) {
+	  gtk_signal_connect (GTK_OBJECT (splash_pixmap), "expose_event",
+			      GTK_SIGNAL_FUNC (expose_event), NULL);
+	  waiting_for_expose = TRUE;
+	  gtk_main ();
+	  waiting_for_expose = FALSE;
+  }
 }
 
 void 
 splash_destroy ()
 {
-  gtk_widget_hide (splash);
-  gtk_widget_destroy (splash);
+	if (splash != NULL) {
+		gtk_widget_hide (splash);
+		gtk_widget_destroy (splash);
+	}
 }
 
