@@ -93,7 +93,12 @@ void gnibbles_load_pixmap ()
 	filename = gnome_unconditional_pixmap_file ("gnibbles/gnibbles.png");
 
 	if (!g_file_exists (filename)) {
-		g_print (_("Couldn't find pixmap file!\n"));
+		char *message =
+		    g_strdup_printf (_("Gnibbles couldn't find pixmap file:\n%s\n\n"
+			"Please check your Gnibbles installation"), filename);
+		GtkWidget *w = gnome_error_dialog (message);
+		gnome_dialog_run_and_close (GNOME_DIALOG(w));
+		g_free (message);
 		exit (1);
 	}
 
@@ -110,7 +115,11 @@ void gnibbles_load_pixmap ()
 		("gnibbles/gnibbles-logo.png");
 
 	if (!g_file_exists (filename)) {
-		g_print (_("Couldn't find pixmap file!\n"));
+		char *message = g_strdup_printf (_("Gnibbles Couldn't find pixmap file:\n%s\n\n"
+			"Please check your Gnibbles instalation"), filename);
+		GtkWidget *w = gnome_error_dialog (message);
+		gnome_dialog_run_and_close (GNOME_DIALOG(w));
+		g_free (message);
 		exit (1);
 	}
 
@@ -138,7 +147,12 @@ void gnibbles_load_level (int level)
 	filename = gnome_unconditional_datadir_file (tmp);
 
 	if ((in = fopen (filename, "r")) == NULL) {
-		printf (_("Ack!  Couldn't load level file %s\n"), filename);
+		char *message = g_strdup_printf (
+                        _("Gnibbles couldn't load level file:\n%s\n\n"
+                         "Please check your Gnibbles installation"), filename);
+                GtkWidget *w = gnome_error_dialog (message);
+                gnome_dialog_run_and_close (GNOME_DIALOG(w));
+                g_free (message);
 		exit (1);
 	}
 
@@ -370,7 +384,7 @@ void gnibbles_add_bonus (int regular)
 gint gnibbles_move_worms ()
 {
 	int i, j, status = 1;
-	int dead[properties->numworms];
+	int *dead = g_new (int, properties->numworms);
 
 	if (boni->missed > MAXMISSED)
 		for (i = 0; i < properties->numworms; i++)
@@ -448,6 +462,7 @@ gint gnibbles_move_worms ()
 		return (CONTINUE);
 
 	gnibbles_play_sound ("crash");
+	g_free (dead);
 	return (NEWROUND);
 }
 
