@@ -1,6 +1,6 @@
 /* gnome-stones - game.h
  *
- * Time-stamp: <1998/08/19 00:31:21 carsten>
+ * Time-stamp: <1998/11/01 16:02:26 carsten>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -24,11 +24,18 @@
 #include <config.h>
 #include <gnome.h>
 #include "types.h"
+#include "object.h"
+
+
+/*****************************************************************************/
+/* Game declarations.  */
 
 
-GStonesGame* game_new  (void);
-void         game_free (GStonesGame *game);
-GStonesGame* game_load (const gchar *name);
+GStonesGame* game_new        (void);
+void         game_free       (GStonesGame *game);
+
+/* Add a plugin to the list of required plugins.  */
+gboolean     game_add_plugin (GStonesGame *game, GStonesPlugin *plugin);
 
 
 #endif
