@@ -1,6 +1,6 @@
 /* gnome-stones - main.c
  *
- * Time-stamp: <1999/03/03 18:09:58 carsten>
+ * Time-stamp: <2000/05/09 18:20:21 martin>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -20,6 +20,7 @@
  */
 #include <config.h>
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <stdlib.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
@@ -1112,13 +1113,13 @@ main (int argc, char *argv[])
   GtkWidget *vbox = NULL;
   GtkWidget *table= NULL;
   
+  gnome_score_init (APP_NAME);
+
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
-  gnome_score_init (APP_NAME);
-
   gnome_init_with_popt_table (APP_NAME, VERSION, argc, argv, options, 0, NULL);
-
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-stones.png");
   /* That's what a gnome application needs:  */
   app= gnome_app_new ("gnome-stones", _("Gnome-Stones"));
   gtk_window_set_policy  (GTK_WINDOW (app), FALSE, FALSE, TRUE);
