@@ -30,7 +30,7 @@
 		     GDK_LEAVE_NOTIFY_MASK          |\
 		     GDK_POINTER_MOTION_MASK)
 
-static GtkWidget *pref_dialog, *scorew;
+static GtkWidget *pref_dialog, *scorew, *markedw;
 static GtkWidget *app, *draw_area, *vb, *appbar;
 static GdkImlibImage *image;
 static GdkPixmap *stones, *mask;
@@ -179,8 +179,13 @@ mark_balls (int x, int y)
 	
 	tagged_count = flood_fill (x, y, field [x][y].color);
 	
-	if (tagged_count > 1)
+	if (tagged_count > 1) {
+		char b[3];
 		ball_timeout_id = gtk_timeout_add (100, move_tagged_balls, 0);
+		sprintf (b, "%.2d", tagged_count);
+		gtk_label_set (GTK_LABEL(markedw), b);
+	} else
+		gtk_label_set (GTK_LABEL(markedw), "00");
 }
 
 static void
@@ -396,7 +401,12 @@ load_scenario (char *fname)
 	g_free( tmp );
 
 	if (!g_file_exists (fn)) {
-		printf (_("Could not find the \'%s\' theme for SameGnome\n"), fn);
+		char *message = g_strdup_printf (
+			_("Could not find the theme:\n%s\n\n"
+			"Please check you Same Gnome instalation"), fn);
+		GtkWidget *w = gnome_error_dialog (message);
+		gnome_dialog_run_and_close (GNOME_DIALOG(w));
+		g_free (message);
 		exit (1);
 	}
 
@@ -411,6 +421,17 @@ load_scenario (char *fname)
 		gdk_imlib_destroy_image (image);
 
 	image = gdk_imlib_load_image (fn);
+
+	if (image == NULL) {
+		char *message = g_strdup_printf (
+			_("Same Gnome can't load the image file:\n%s\n\n"
+			 "Please check your Same Gnome installation"), fn);
+		GtkWidget *w = gnome_error_dialog (message);
+		gnome_dialog_run_and_close (GNOME_DIALOG(w));
+		g_free (message);
+		exit (1);
+	}
+
 	gdk_imlib_render (image, image->rgb_width, image->rgb_height);
 
 	stones = gdk_imlib_move_image (image);
@@ -434,7 +455,10 @@ load_scenario (char *fname)
 static void
 set_selection (GtkWidget *widget, void *data)
 {
-	selected_scenario.scenario = data;
+	if (selected_scenario.scenario)
+		free (selected_scenario.scenario);
+
+	selected_scenario.scenario = strdup (data);
 }
 
 static void
@@ -518,6 +542,7 @@ fill_menu (GtkWidget *menu)
 	        itemno++;
 	}
 	closedir (dir);
+	g_free (dname);
 }
 
 static void
@@ -555,7 +580,7 @@ game_preferences_callback (GtkWidget *widget, void *data)
 			GNOME_STOCK_BUTTON_OK, GNOME_STOCK_BUTTON_CANCEL,
 			NULL);
 	gnome_dialog_set_parent (GNOME_DIALOG (pref_dialog), GTK_WINDOW (app));
-	gtk_signal_connect (GTK_OBJECT(pref_dialog), "delete_event",
+	gtk_signal_connect (GTK_OBJECT(pref_dialog), "close",
 			    GTK_SIGNAL_FUNC (cancel), NULL);
 
 	omenu = gtk_option_menu_new ();
@@ -783,7 +808,7 @@ static const struct poptOption options[] = {
 int
 main (int argc, char *argv [])
 {
-	GtkWidget *label;
+	GtkWidget *label, *separator;
 	GnomeClient *client;
 
 	gnome_score_init("same-gnome");
@@ -838,6 +863,14 @@ main (int argc, char *argv [])
 
 	create_same_board (fname);
 
+	separator = gtk_vseparator_new ();
+	label = gtk_label_new (_("Marked: "));
+	markedw = gtk_label_new ("00");
+
+	gtk_box_pack_start(GTK_BOX(appbar), label, FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(appbar), markedw, FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(appbar), separator, FALSE, TRUE, 5);
+	
 	label = gtk_label_new (_("Score: "));
 	scorew = gtk_label_new ("");
 	set_score (score);
@@ -850,10 +883,7 @@ main (int argc, char *argv [])
 	
 	g_free (fname);
 
-	gtk_widget_show (vb);
-	gtk_widget_show (GTK_WIDGET(label));
-	gtk_widget_show (GTK_WIDGET(scorew));
-        gtk_widget_show (app);
+        gtk_widget_show_all (app);
 
 	gtk_main ();
 	return 0;
